-- Tests for borderbasis.cpkg
-------------------------------
Package $apcocoa/ts/borderbasis

Define Initialize()
EndDefine;


--BBasis communication test
Define TestBBasis1()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    I := Ideal([x^2,y^2,z^2]);
    Result := BB.BBasis(I);
    Expected := [z^2, y^2, x^2, yz^2, xz^2, y^2z, x^2z, xy^2, x^2y, xyz^2, xy^2z, x^2yz];
    $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "Wrong BorderBasis!");
  EndUsing;
EndDefine;

Define TestBorder1()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    OO := [1];
    Result := BB.Border(OO);
    Expected := [z, y, x];
    $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "Wrong order ideal!");
  EndUsing;
EndDefine;

Define TestBorder2()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    OO := [x + y];
    Catch BB.Border(OO); In E EndCatch;
    $apcocoa/ts/assert.AssertTrue(Type(E) = ERROR,
                                  "Incorrect input should have raised an error!");
    $apcocoa/ts/assert.AssertEqualsExact(GetErrMesg(E),
                                         "Border: Argument 'OO' must be a list of terms!",
                                         "Unexpected error occurred!");
  EndUsing;
EndDefine;

Define TestBorder3()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    OO := [1, 2];
    Catch BB.Border(OO); In E EndCatch;
    $apcocoa/ts/assert.AssertTrue(Type(E) = ERROR,
                                  "Incorrect input should have raised an error!");
    $apcocoa/ts/assert.AssertEqualsExact(GetErrMesg(E),
                                         "Border: Argument 'OO' must be a list of terms!",
                                         "Unexpected error occurred!");
  EndUsing;
EndDefine;

Define TestBox1()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    D := [0, 0, 0];
    Result := BB.Box(D);
    Expected := [ Poly(1) ];
    $apcocoa/ts/assert.AssertEqualsExact(Result,
                                         Expected,
                                         "Wrong order ideal returned!");
  EndUsing;
EndDefine;

Define TestBox2()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    D := [0, 0];
    Catch BB.Box(D); In E EndCatch;
    $apcocoa/ts/assert.AssertTrue(Type(E) = ERROR,
                                  "Incorrect input should have raised an error!");
    $apcocoa/ts/assert.AssertEqualsExact(GetErrMesg(E),
                                         "Box: Length of input list does not match number of indeterminants!",
                                         "Unexpected error occurred!");
  EndUsing;
EndDefine;

Define TestBox3()
  TestRing ::= QQ[x,y,z], DegRevLex;
  Using TestRing Do
    D := [-1, 0, 0];
    Catch BB.Box(D); In E EndCatch;
    $apcocoa/ts/assert.AssertTrue(Type(E) = ERROR,
                                  "Incorrect input should have raised an error!");
    $apcocoa/ts/assert.AssertEqualsExact(GetErrMesg(E),
                                         "Box: Input list must not contain negative numbers!",
                                         "Unexpected error occurred!");
  EndUsing;
EndDefine;
EndPackage;