-- Tests for iml.cpkg
Package $apcocoa/ts/iml


Define Initialize()
EndDefine;


--Solve with solution
Define TestIML01()

TestRing::=QQ[x];

Using TestRing Do

  M := Mat([[2,6,8], [0,2,1]]);
  B := Mat([[1], [2]]);
  Result:=IML.Solve(M, B);
  Expected:=Mat([[-5/2],[1],[0]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "Wrong solution in QQ!");

EndUsing;

EndDefine;



--Solve with solution in Z/19Z
Define TestIML02()

TestRing::=ZZ/(19)[x];

Using TestRing Do

  M := BringIn(Mat([[1,3,4], [0,2,1]]));
  B := BringIn(Mat([[1], [2]]));
  Result:=IML.Solve(M, B);
  Expected:=Mat([[-2 % 19],[1 % 19],[0 % 19]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "Wrong Solution in ZZ/(19)!");

EndUsing;

EndDefine;



--Solve with infeasible system
Define TestIML03()

TestRing::=QQ[x];

Using TestRing Do

  M := Mat([ [1,3,4], [0,2,1], [1,3,4] ]);
  B := Mat([ [1], [2], [0] ]);
  Result:=IML.Solve(M, B);
  Expected:=Mat([[ ]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result,Expected, "TODO: Some error message.");

EndUsing;

EndDefine;



--REF over finite field
Define TestIML04()

TestRing::=ZZ/(239)[x];

Using TestRing Do
  M := Mat([[1, 2, 3], [4, 5, 6], [7, 8, 9], [11, 12, 13]]);
  Result:=IML.REF(M, FALSE);
  Expected:=Mat([
  [1 % 239, 2 % 239, 3 % 239],
  [0 % 239, 1 % 239, 2 % 239],
  [0 % 239, 0 % 239, 0 % 239],
  [0 % 239, 0 % 239, 0 % 239]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "Wrong REF over ZZ/(239).");
  
EndUsing;

EndDefine;



--RREF over finite field
Define TestIML05()

TestRing::=ZZ/(239)[x];

Using TestRing Do
  M := Mat([[1, 2, 3], [4, 5, 6], [7, 8, 9], [11, 12, 14]]);
  Result:=IML.REF(M, TRUE);
  Expected:=Mat([
  [1 % 239, 0 % 239, 0 % 239],
  [0 % 239, 1 % 239, 0 % 239],
  [0 % 239, 0 % 239, 1 % 239],
  [0 % 239, 0 % 239, 0 % 239]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result,Expected, "Wrong RREF over ZZ/(239).");
EndUsing;

EndDefine;



--RREF with option p
Define TestIML06()

TestRing::=QQ[x];

Using TestRing Do
  M := Mat([[1, 2, 3], [4, 5, 6], [7, 8, 9], [11, 12, 14]]);
  Result:=IML.REF(M, 11, TRUE);
  Expected:=Mat([
  [1, 0, 0],
  [0, 1, 0],
  [0, 0, 1],
  [0, 0, 0]]);
  $apcocoa/ts/assert.AssertEqualsExact(Result,Expected, "Wrong RREF over ZZ/(11).");
EndUsing;

EndDefine;


EndPackage;